@@ -14,7 +14,14 @@ from .entity_manager import EntityManager
 from .user import User
 from .film import Film
 from .shot import Sequence, Shot
-from .task import Task
+from .task import Task, Tasks
+from .asset import Asset, AssetFamily, AssetType, AssetTypeCollection
+from .file import (
+    TrackedFile,
+    TrackedFolder,
+    Revision,
+    TrackedFolderRevision,
+)
 
 
 class ProjectSettings(BaseProjectSettings):
@@ -37,6 +44,7 @@ class Project(BaseProject, flow.InjectionProvider):
     user            = flow.Child(UserProfile)
     synchronization = flow.Child(Synchronization).ui(expanded=True)
     films           = flow.Child(FilmCollection).ui(expanded=True)
+    asset_types     = flow.Child(AssetTypeCollection)
     admin           = flow.Child(Admin)
 
     asset_lib = flow.Child(flow.Object).ui(hidden=True)
@@ -52,8 +60,24 @@ class Project(BaseProject, flow.InjectionProvider):
             return Sequence
         elif slot_name == 'libreflow.baseflow.shot.Shot':
             return Shot
+        elif slot_name == 'libreflow.baseflow.asset.Asset':
+            return Asset
+        elif slot_name == 'libreflow.baseflow.asset.AssetFamily':
+            return AssetFamily
+        elif slot_name == 'libreflow.baseflow.asset.AssetType':
+            return AssetType
         elif slot_name == 'libreflow.baseflow.task.ManagedTask':
             return Task
+        elif slot_name == 'libreflow.baseflow.task.ManageTaskCollection':
+            return Tasks
+        elif slot_name == 'libreflow.baseflow.file.TrackedFile':
+            return TrackedFile
+        elif slot_name == 'libreflow.baseflow.file.TrackedFolder':
+            return TrackedFolder
+        elif slot_name == 'libreflow.baseflow.file.Revision':
+            return Revision
+        elif slot_name == 'libreflow.baseflow.file.TrackedFolderRevision':
+            return TrackedFolderRevision
         elif slot_name == 'libreflow.baseflow.users.User':
             return User
         elif slot_name == 'libreflow.baseflow.ProjectSettings':
