@@ -18,7 +18,11 @@ class Shot(BaseShot):
         mgr = self.root().project().get_task_manager()
 
         for dt in mgr.default_tasks.mapped_items():
-            if not self.tasks.has_mapped_name(dt.name()) and not dt.optional.get():
+            if (
+                not self.tasks.has_mapped_name(dt.name())
+                and not dt.optional.get()
+                and dt.template.get() == 'shot'
+            ):
                 t = self.tasks.add(dt.name())
                 t.enabled.set(dt.enabled.get())
         
@@ -35,6 +39,8 @@ class Shots(ShotCollection):
         s = super(Shots, self).add(name, object_type)
         s.ensure_tasks()
 
+        return s
+
 
 class Sequence(BaseSequence):
     
